@@ -19,6 +19,9 @@
 %% -*- texinfo -*-
 %% @documentencoding UTF-8
 %% @deftypefn  {Function File}  {} disp (@var{x})
+%% @deftypefnx {Function File}  {} disp (@var{x}, 'unicode')
+%% @deftypefnx {Function File}  {} disp (@var{x}, 'ascii')
+%% @deftypefnx {Function File}  {} disp (@var{x}, 'flat')
 %% @deftypefnx {Function File}  {@var{s} =} disp (@var{x})
 %% Display the value of a symbolic expression.
 %%
@@ -79,14 +82,14 @@ function varargout = disp(x, wh)
     case 'unicode'
       s = x.unicode;
     otherwise
-      error('invalid display type')
+      print_usage ();
   end
   s = make_indented(s);
 
   if (nargout == 0)
     disp(s)
   else
-    varargout = {s};
+    varargout = {disp(s)};  % add a newline
   end
 end
 
@@ -105,12 +108,12 @@ end
 %!test
 %! syms x
 %! s = disp(sin(x));
-%! assert(strcmp(s, '  sin(x)'))
+%! assert(strcmp(s, sprintf('  sin(x)\n')))
 
 %!test
 %! syms x
 %! s = disp(sin(x/2), 'flat');
-%! assert(strcmp(s, '  sin(x/2)'))
+%! assert(strcmp(s, sprintf('  sin(x/2)\n')))
 
 %!test
 %! % Examples of 2x0 and 0x2 empty matrices:
@@ -120,6 +123,6 @@ end
 %! assert (isequal (size (b2x0), [2 0]))
 %! assert (isequal (size (b0x2), [0 2]))
 %! s = disp(b2x0);
-%! assert(strcmp(s, '  []'))
+%! assert(strcmp(s, sprintf('  []\n')))
 %! s = disp(b0x2);
-%! assert(strcmp(s, '  []'))
+%! assert(strcmp(s, sprintf('  []\n')))
