@@ -103,8 +103,9 @@ function r = isAlways(p, varargin)
     '    #FIXME; Boolean, simplify more than once?'
     '    if r in (S.true, S.false):'
     '        return bool(r)'
-    '    # hopefully we get sympy patched for some of this'
-    '    if sympy.__version__ == "0.7.5" or sympy.__version__.startswith("0.7.6"):'
+    '    # FIXME: hopefully we get sympy patched for some of this'
+    '    #if sympy.__version__ in ("0.7.5", "0.7.6") or sympy.__version__.startswith("0.7.7"):'
+    '    if True:'
     '        if isinstance(p, Equality):'
     '            r = Eq(sp.simplify(p.lhs - p.rhs), 0)'
     '            r = simplify(r)'
